---------------------------------
API reference for storage drivers
---------------------------------

.. currentmodule:: zaqar.storage.base

.. autoclass:: DataDriverBase
   :noindex:
   :members:

.. autoclass:: ControlDriverBase
   :noindex:
   :members:

.. autoclass:: Queue
   :noindex:
   :members:

.. autoclass:: Message
   :noindex:
   :members:

.. autoclass:: Claim
   :noindex:
   :members:


--------------
MongoDB Driver
--------------

.. automodule:: zaqar.storage.mongodb
